Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/typedal/__about__.py | (no class) | 1 | 0 | 0 | 100%
src/typedal/__init__.py | (no class) | 5 | 0 | 2 | 100%
src/typedal/caching.py | _TypedalCache | 0 | 0 | 0 | 100%
src/typedal/caching.py | _TypedalCacheDependency | 0 | 0 | 0 | 100%
src/typedal/caching.py | (no class) | 52 | 0 | 2 | 100%
src/typedal/cli.py | (no class) | 51 | 0 | 13 | 100%
src/typedal/config.py | TypeDALConfig | 4 | 0 | 8 | 100%
src/typedal/config.py | (no class) | 53 | 0 | 3 | 100%
src/typedal/core.py | Relationship | 40 | 0 | 2 | 100%
src/typedal/core.py | TypeDAL | 96 | 0 | 0 | 100%
src/typedal/core.py | TableProtocol | 0 | 0 | 1 | 100%
src/typedal/core.py | Table | 0 | 0 | 0 | 100%
src/typedal/core.py | TableMeta | 81 | 0 | 4 | 100%
src/typedal/core.py | TypedField | 0 | 0 | 56 | 100%
src/typedal/core.py | _TypedTable | 0 | 0 | 0 | 100%
src/typedal/core.py | TypedTable | 103 | 0 | 16 | 100%
src/typedal/core.py | TypedRows | 82 | 0 | 0 | 100%
src/typedal/core.py | QueryBuilder | 227 | 0 | 12 | 100%
src/typedal/core.py | PaginatedRows | 14 | 0 | 0 | 100%
src/typedal/core.py | TypedSet | 0 | 0 | 6 | 100%
src/typedal/core.py | (no class) | 246 | 0 | 41 | 100%
src/typedal/fields.py | (no class) | 42 | 0 | 0 | 100%
src/typedal/for_py4web.py | Fixture | 0 | 0 | 0 | 100%
src/typedal/for_py4web.py | DAL | 0 | 0 | 7 | 100%
src/typedal/for_py4web.py | (no class) | 9 | 0 | 5 | 100%
src/typedal/for_web2py.py | AuthGroup | 2 | 0 | 0 | 100%
src/typedal/for_web2py.py | AuthMembership | 0 | 0 | 0 | 100%
src/typedal/for_web2py.py | AuthPermission | 0 | 0 | 0 | 100%
src/typedal/for_web2py.py | AuthEvent | 0 | 0 | 0 | 100%
src/typedal/for_web2py.py | (no class) | 25 | 0 | 0 | 100%
src/typedal/helpers.py | DummyQuery | 3 | 0 | 0 | 100%
src/typedal/helpers.py | (no class) | 33 | 0 | 0 | 100%
src/typedal/mixins.py | Mixin | 0 | 0 | 0 | 100%
src/typedal/mixins.py | TimestampsMixin | 4 | 0 | 0 | 100%
src/typedal/mixins.py | SlugMixin | 23 | 0 | 0 | 100%
src/typedal/mixins.py | (no class) | 27 | 0 | 0 | 100%
src/typedal/serializers/as_json.py | SerializedJson | 3 | 0 | 24 | 100%
src/typedal/serializers/as_json.py | (no class) | 11 | 0 | 1 | 100%
src/typedal/types.py | Query | 0 | 0 | 0 | 100%
src/typedal/types.py | Expression | 0 | 0 | 0 | 100%
src/typedal/types.py | Set | 0 | 0 | 0 | 100%
src/typedal/types.py | OpRow | 0 | 0 | 0 | 100%
src/typedal/types.py | Reference | 0 | 0 | 0 | 100%
src/typedal/types.py | Field | 0 | 0 | 0 | 100%
src/typedal/types.py | Rows | 0 | 0 | 0 | 100%
src/typedal/types.py | Validator | 0 | 0 | 0 | 100%
src/typedal/types.py | _Types | 0 | 0 | 0 | 100%
src/typedal/types.py | Pagination | 0 | 0 | 0 | 100%
src/typedal/types.py | PaginateDict | 0 | 0 | 0 | 100%
src/typedal/types.py | CacheMetadata | 0 | 0 | 0 | 100%
src/typedal/types.py | PaginationMetadata | 0 | 0 | 0 | 100%
src/typedal/types.py | Metadata | 0 | 0 | 0 | 100%
src/typedal/types.py | (no class) | 64 | 0 | 0 | 100%
src/typedal/web2py_py4web_shared.py | AuthUser | 2 | 0 | 0 | 100%
src/typedal/web2py_py4web_shared.py | (no class) | 17 | 0 | 0 | 100%
Total |  | 1320 | 0 | 203 | 100%

No items found using the specified filter.